@@ -60,11 +60,18 @@ void		Apple_memory_write();
  * note. the zero page and the stack page must be mapped to memory
  */
 
+#if 1
 #define	ZERO_PAGE_READ(addr)	(*(Read_Page_Table[0]+((addr) & 0xFF)))
 #define	ZERO_PAGE_WRITE(addr,data) *(Write_Page_Table[0]+((addr) & 0xFF))=data
 
 #define	STACK_READ(addr)	(*(Read_Page_Table[1]+((addr) & 0xFF)))
 #define	STACK_WRITE(addr,data)	(*(Write_Page_Table[1]+((addr) & 0xFF)))=data
+#else
+#define	ZERO_PAGE_READ(addr)		Apple_memory_read(addr)
+#define	ZERO_PAGE_WRITE(addr,data)	Apple_memory_write((addr),(data))
+#define	STACK_READ(addr)		Apple_memory_read(addr)
+#define	STACK_WRITE(addr,data)		Apple_memory_write((addr),(data))
+#endif
 
 /*
  * macros for the stack
@@ -77,18 +84,6 @@ void		Apple_memory_write();
  * SET_X(c): set flag X to 1 if c is not zero, clear flag otherwise
  * GET_X(c): return non-zero value if flag X is 1, 0 otherwise
  */
-#define N_BIT	(1<<7)
-#define V_BIT	(1<<6)
-/*
- *	owing to a bug in 6502, the bit 5 must be always 1;
- *	otherwise, programs like DOS 3.3 will break down
- *	see instructions in $9FF4-$9FF5 of DOS 3.3
- */
-#define B_BIT	(1<<4)
-#define D_BIT	(1<<3)
-#define I_BIT	(1<<2)
-#define Z_BIT	(1<<1)
-#define C_BIT	(1<<0)
 #define	SET_N(c)	if (c) P |= N_BIT; else P &= ~N_BIT
 #define	SET_V(c)	if (c) P |= V_BIT; else P &= ~V_BIT
 #define	SET_B(c)	if (c) P |= B_BIT; else P &= ~B_BIT
@@ -319,11 +314,9 @@ resume_execution:
 #ifdef	SLAVE_PROCESSOR
 	   SAVE_CONTEXT( context );
 #endif
-
 	   /*
 	    * fetch & decode instruction
 	    */
-
 	   opcode = INSTRUCTION_FETCH();
 
 #ifdef	RUN_TIME_TRANSLATION
@@ -1678,5 +1671,12 @@ resume_execution:
 	   Exception_Register &= ~SIG_6502_TIMER;
 	   return SIG_6502_TIMER;
 	}
+
+	for(easp1=0;easp1<32;easp1++) {
+	   if ((1<<easp1)&Exception_Register) {
+	      Exception_Register &= ~(1<<easp1);
+	      return (1<<easp1);
+	   }
+	}
 	return Exception_Register;
 }
