@@ -8,6 +8,7 @@
 #define	SIG_6502_TIMER		(1<<4)
 #define	SIG_6502_CONTEXT	(1<<5)
 #define	SIG_6502_MEMORY		(1<<6)
+#define	SIG_6502_EMULATION	(1<<7)
 
 typedef	struct	{
 	ADDR	PC;
@@ -18,6 +19,20 @@ typedef	struct	{
 	BYTE	S;
 	} AppleCPUContextStruct;
 
+/* P register flags */
+#define N_BIT	(1<<7)
+#define V_BIT	(1<<6)
+/*
+ *	owing to a bug in 6502, the bit 5 must be always 1;
+ *	otherwise, programs like DOS 3.3 will break down
+ *	see instructions in $9FF4-$9FF5 of DOS 3.3
+ */
+#define B_BIT	(1<<4)
+#define D_BIT	(1<<3)
+#define I_BIT	(1<<2)
+#define Z_BIT	(1<<1)
+#define C_BIT	(1<<0)
+
 /* function prototypes */
 void init_6502(void);
 void assert_RES(void);
