@@ -16,10 +16,19 @@ static APPLE_TICK NextVBLRecalibrate;
 static APPLE_TICK VBLTimeBase;
 static void VBLRecalibrate(void*);
 
+void	(*VBLCallback)();
+
 void initVBL(void)
 {
+	VBLCallback=NULL;
 	if (MachineType >= APPLE_IIE)
-	   submit_micro_job( VBLTimeBase+FRAME_TICKS, VBLRecalibrate, NULL );
+	   submit_micro_job( VBLTimeBase+VBL_START*SCAN_LINE_TICKS, 
+	      VBLRecalibrate, NULL );
+}
+
+void addVBLCallback(void (*callback)())
+{
+	VBLCallback=callback;
 }
 
 int isVBL(void)
@@ -39,5 +48,7 @@ static void VBLRecalibrate(void *arg)
 	frames = (AppleClock - VBLTimeBase)/FRAME_TICKS;
 	VBLTimeBase += FRAME_TICKS*frames;
 	NextVBLRecalibrate+=FRAME_TICKS;
+	if (VBLCallback)
+	   (*VBLCallback)();
 	submit_micro_job( NextVBLRecalibrate, VBLRecalibrate, NULL );
 }
