@@ -5,6 +5,7 @@
  */
 #ifndef VIDEO_H
 #define VIDEO_H
+#include "x_window.h"
 
 #define SCANLINE_MODE_BLANK	0
 #define SCANLINE_MODE_TEXT	1
@@ -13,10 +14,9 @@
 #define SCANLINE_MODE_TEXT80	4
 #define SCANLINE_MODE_DLORES	5
 #define SCANLINE_MODE_DHIRES	6
+#define NO_OF_SCANLINE_MODES	7
 
 extern unsigned ScanlineOffsetTable[192];
-extern unsigned AppleColourPixel[16];
-extern unsigned AppleColourQuad[16];
 
 typedef struct {
 	int y;
@@ -35,18 +35,20 @@ typedef struct {
 #define SCANLINE_STATE_DIRTY	1
 #define SCANLINE_STATE_DRAWN	2
 
-extern void initScanlineData(void);
-extern void drawBlankScanline(scanline_t*);
-extern void drawTextScanline(scanline_t*);
-extern void drawLowresScanline(scanline_t*);
-extern void drawHiresScanline(scanline_t*);
-extern void drawText80Scanline(scanline_t*);
-extern void drawDLoresScanline(scanline_t*);
-extern void drawDHiresScanline(scanline_t*);
-extern void changeCharSet(int);
+typedef struct {
+	void (*initScanlineData)( DisplayContext *);
+	void (*drawBlankScanline)(scanline_t*);
+	void (*drawTextScanline)(scanline_t*);
+	void (*drawLoresScanline)(scanline_t*);
+	void (*drawHiresScanline)(scanline_t*);
+	void (*drawText80Scanline)(scanline_t*);
+	void (*drawDLoresScanline)(scanline_t*);
+	void (*drawDHiresScanline)(scanline_t*);
+	void (*changeCharSet)(int);
+} VideoModeDriver;
 
 void initScreen(Display *);
 int drawScreen(void);
-void updateScreen(void);
+void updateScreen(DisplayContext *);
 
 #endif /* VIDEO_H */
