@@ -1,7 +1,16 @@
+/*
+ * yae.h
+ *
+ * declare functions defined in various modules of YAE
+ *
+ */
+#ifndef _YAE_H_
+#define _YAE_H_
+
 /* disk2.c */
 void init_disk2(void);
-int mount_disk( int, int, char* );
-int unmount_disk( int, int );
+int mount_disk( int, int );
+int unmount_disk( void );
 
 /* gcr.c */
 void SectorsToNibbles( BYTE *, BYTE *, int, int );
@@ -27,7 +36,11 @@ void remapHiresRead(void);
 void remapHiresWrite(void);
 void remapCXROM(void);
 void remapLCRead(void);
-void remapLCWrite(void);
+void remapLCLoWrite(void);
+void remapLCHiWrite(void);
+
+/* monitor.c */
+void enterMonitor();
 
 /* paddle.c */
 void press_button( int );
@@ -55,3 +68,8 @@ void execute_micro_jobs(void);
 /* vbl.c */
 void initVBL(void);
 int isVBL(void);
+
+/* confile.c */
+void ParseConfigFile(void);
+
+#endif /* _YAE_H_ */
